# hclib

![PyPI](https://img.shields.io/pypi/v/hclib.svg)

This is a wrapper to connect to [hack.chat](https://github.com/hack-chat/main) instances.

**Note**: This project has been deprecated for the following reasons:
1. The hack.chat API is not machine-friendly. There was no documentation or standard way of accessing it. This library was created by reading source code, not documnetation, and data is processed using hardcoded string lengths, etc.
1. The new hack.chat API is 100% backwards-compatible, so this library will still work just as good as it used to. 
1. [hack.chat](https://github.com/AndrewBelt/hack.chat) was stopped being developer by the original author and the [new repository](https://github.com/hack-chat/main) is neither seriously nor actively developed.  
1. As beautiful as the idea of hack.chat was, nobody uses it.

# Documentation

1. Start the REPL:
    - Windows: `python`
    - Other: `python3`
1. Import: `import hclib`
1. View: `help(hclib)`

# License

This project is under the [MIT license](LICENSE).
